.. image:: https://img.shields.io/pypi/v/jaraco.xkcd.svg
   :target: https://pypi.org/project/jaraco.xkcd

.. image:: https://img.shields.io/pypi/pyversions/jaraco.xkcd.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.xkcd/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.xkcd

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/jaraco-xkcd/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/jaraco-xkcd/branch/master

.. .. image:: https://readthedocs.org/projects/jaracoxkcd/badge/?version=latest
..    :target: https://jaracoxkcd.readthedocs.io/en/latest/?badge=latest
